%define apache_version 1.3.9
%define mod_ssl_version 2.4.10-1.3.9
%define openssl_version 0.9.4
%define bsafe_version 3.0
%define mm_version 1.0.12

Summary: Leading World Wide Web server with SSL support
Name: secureweb
Version: 3.1
Release: 2
Group: System Environment/Daemons

Source0: ftp://ftp.apache.org/apache/dist/apache_%{apache_version}.tar.gz
Source1: secureweb-index.html
Source2: logotype.png
Source3: rsasec_55_clr_web1.gif
Source4: httpsd.init
Source5: secureweb.logrotate
Source6: secureweb-access.conf
Source7: secureweb-httpd.conf
Source8: secureweb-srm.conf
Source9: ftp://ftp.cohprog.com/pub/apache/module/1.3.0/mod_bandwidth.c
Source10: mod_put.c
Source11: http://www.snert.com/Software/Throttle/mod_throttle208.tgz

Patch0: apache_1.3.9-httpsd.patch
Patch1: apache_1.3.9-apxs.patch
Patch4: apache_1.3.9-srvname.patch
Patch6: apache_1.3.9-maxprocs.patch
Patch8: apache_1.3.9-sxnetssl.patch

Source15: openssl-%{openssl_version}.tar.gz
NoSource: 15
Source16: bsafe-%{bsafe_version}.tar.gz
NoSource: 16
Source17: mm-%{mm_version}.tar.gz
Source18: Makefile.certificate
# this is a patch, but we want to treat it like a source file
Source19: openssl-0.9.4-bsafenew.patch
NoSource: 19

Source20: mod_ssl-%{mod_ssl_version}.tar.gz
Patch20: mod_ssl-2.4.5-1.3.9-bsafe.patch
Patch22: mod_ssl-2.4.5-1.3.9-docs.patch

License: Export restricted / not for redistribution / single CPU
BuildRoot: /var/tmp/%{name}-root
Requires: /etc/mime.types
Prereq: /sbin/chkconfig, /bin/mktemp, /bin/rm, mailcap, grep, textutils
Obsoletes: apache-ssl apache-ssl-utils apache
Provides: webserver apache

%description
Secure Web server consists of the popular Apache web server with
extensions to enable secure transactions.  Secure Socket Layer (SSL)
version 2 and 3 are supported, as well as the newer TLSv1.  Secure Web
Server replaces Apache if you already have it installed, as it
supplies all of Apache's functionality and more.

%package devel
Group: Development/Libraries
Summary: Module development tools for the Apache Web Server
Obsoletes: apache-devel
Provides: apache-devel

%description devel
The secureweb-devel package contains the source code for the Apache
Web server and the APXS binary you'll need to build Dynamic Shared
Objects (DSOs) for Apache.

If you are installing the Apache Web server, and you want to be able
to compile or develop additional modules for Apache, you'll need to
install this package.

%package manual
Group: Documentation
Summary: Manual and reference for the Apache web server.
Obsoletes: apache-manual
Provides: apache-manual

%description manual
The secureweb-manual package contains the complete manual and
reference guide for the Apache web server and SSL module.  If you need
documentation installed on the local machine, install this package.
The information can also be referenced online at
http://www.apache.org/docs/.


%prep
# first, unpack all sources. Use a meta toplevel directory "secureweb."
%setup -q -c -n secureweb -a 15 -a 16 -a 17 -a 20
tar xz -C apache_%{apache_version} -f %{SOURCE11}

# patches for Red Hat specific changes to apache
cd apache_%{apache_version}
%patch0 -p1 -b .httpsd
%patch1 -p1 -b .apxs
%patch4 -p1 -b .srvname
%patch6 -p1 -b .maxprocs

# add sxnet module
cd src/modules
tar xf $RPM_BUILD_DIR/secureweb/mod_ssl-%{mod_ssl_version}/pkg.contrib/sxnet.tar
cd ../..
%patch8 -p1 -b .sxnetssl
cd ..

# patch OpenSSL for BSAFE
cd openssl-%{openssl_version}
patch -s -p1 -b -z .bsafenew < %{SOURCE19}
# make sure this gets regenerated
rm apps/progs.h
cd ..

# patch mod_ssl for BSAFE
cd mod_ssl-%{mod_ssl_version}
%patch20 -p1 -b .bsafe
%patch22 -p1 -b .docs
cd ..

%build
# first, build OpenSSL
cd openssl-%{openssl_version}
./Configure --prefix=/usr --openssldir=/usr/lib/ssl \
	--install-prefix=$RPM_BUILD_ROOT \
	linux-elf \
	bsafe \
	no-rc5 \
	-I`pwd`/../bsafe/include \
	-L`pwd`/../bsafe/lib

# fix up install path
perl util/perlpath.pl /usr/bin
perl util/

make dep
make
cd ..

# now build mm
cd mm-%{mm_version}
CFLAGS="$RPM_OPT_FLAGS" \
	./configure \
	--prefix=/usr \
	--disable-shared
make
cd ..

# configure mod_ssl/apache
cd mod_ssl-%{mod_ssl_version}
OPTIM="$RPM_OPT_FLAGS" EAPI_MM=../mm-%{mm_version} \
	./configure \
	--with-apache=../apache_%{apache_version} \
	--with-ssl=../openssl-%{openssl_version} \
	--with-mm=../mm-%{mm_version} \
	--with-bsafe=../bsafe/lib \
	--prefix=/usr --with-layout=RedHat \
	--target=httpsd \
	--add-module=$RPM_SOURCE_DIR/mod_bandwidth.c \
	--add-module=$RPM_SOURCE_DIR/mod_put.c \
	--activate-module=src/modules/throttle/mod_throttle.o \
	--enable-shared=sxnet \
	--enable-module=all \
	--enable-shared=max \
	--disable-rule=WANTHSREGEX \
	--disable-module=auth_dbm \
	--with-perl=/usr/bin/perl \
	--enable-suexec \
	--suexec-docroot=/home/httpd/html \
	--suexec-caller=nobody

exit 
cd ../apache_%{apache_version}
make
	
%install
rm -rf $RPM_BUILD_ROOT

# first install OpenSSL functionality
cd openssl-%{openssl_version}
make install
# remove stuff we don't want from OpenSSL
rm -fr $RPM_BUILD_ROOT/usr/{certs,include,private}
rm $RPM_BUILD_ROOT/usr/lib/*.a
mv $RPM_BUILD_ROOT/usr/bin $RPM_BUILD_ROOT/usr/sbin
strip $RPM_BUILD_ROOT/usr/sbin/openssl
cd ..

# now install apache functionality
cd apache_%{apache_version}
make install root=$RPM_BUILD_ROOT
cd ..
strip $RPM_BUILD_ROOT/usr/sbin/httpsd

# install SYSV init stuff
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m755 $RPM_SOURCE_DIR/httpsd.init \
	$RPM_BUILD_ROOT/etc/rc.d/init.d/httpsd

for I in 0 1 2 6; do
	mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc$I.d
	ln -s ../init.d/httpsd $RPM_BUILD_ROOT/etc/rc.d/rc$I.d/K15httpsd
done
for I in 3 5; do
	mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc$I.d
	ln -s ../init.d/httpsd $RPM_BUILD_ROOT/etc/rc.d/rc$I.d/S85httpsd
done

# install log rotation stuff
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
install -m644 $RPM_SOURCE_DIR/secureweb.logrotate \
	$RPM_BUILD_ROOT/etc/logrotate.d/secureweb

ln -s ../../var/log/httpd $RPM_BUILD_ROOT/etc/httpd/logs
ln -s ../../usr/lib/apache $RPM_BUILD_ROOT/etc/httpd/modules

# default home page
install -m644 $RPM_SOURCE_DIR/secureweb-index.html \
        $RPM_BUILD_ROOT/home/httpd/html/index.html
install -m644 $RPM_SOURCE_DIR/logotype.png \
	$RPM_BUILD_ROOT/home/httpd/html
install -m644 $RPM_SOURCE_DIR/rsasec_55_clr_web1.gif \
	$RPM_BUILD_ROOT/home/httpd/html

# replace Apache's default config files with our own versions
install -m644 $RPM_SOURCE_DIR/secureweb-access.conf \
	$RPM_BUILD_ROOT/etc/httpd/conf/access.conf

install -m644 $RPM_SOURCE_DIR/secureweb-httpd.conf \
	$RPM_BUILD_ROOT/etc/httpd/conf/httpd.conf
pushd $RPM_BUILD_ROOT/etc/httpd/conf
rm httpsd.conf
ln -s httpd.conf httpsd.conf
popd

install -m644 $RPM_SOURCE_DIR/secureweb-srm.conf \
	$RPM_BUILD_ROOT/etc/httpd/conf/srm.conf

# install certificate makefile
install -m755 $RPM_SOURCE_DIR/Makefile.certificate \
	$RPM_BUILD_ROOT/etc/httpd/conf/Makefile

# fix up paths to perl
find $RPM_BUILD_ROOT -type f | \
	xargs grep -l "/usr/local/bin/perl5" | \
	xargs perl -pi -e "s|/usr/local/bin/perl5|/usr/bin/perl|g;"
find $RPM_BUILD_ROOT -type f | \
	xargs grep -l "/usr/local/bin/perl" | \
	xargs perl -pi -e "s|/usr/local/bin/perl|/usr/bin/perl|g;"

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if [ -d /var/log/httpd ]; then
  if [ "`ls /var/log/httpd`" != "" ]; then
    # because the pre script of apache will remove log files,
    # and the user may want to save them, we'll hide them somewhere
    mkdir /var/tmp/httpd-logs
    cp -a /var/log/httpd/* /var/tmp/httpd-logs
  fi
fi

# move old key/certificate if upgrading SWS 1.x/2.x
# make sure there isn't a new key / cert combo first
if [ $1 != 0 ]; then
  if [ -f /etc/httpd/conf/httpsd.key -a ! -f /etc/httpd/conf/ssl.key/server.key ]; then
    mkdir /var/tmp/httpsd-keys
    cp -a /etc/httpd/conf/httpsd.key /var/tmp/httpsd-keys
    cp -a /etc/httpd/conf/httpsd.crt /var/tmp/httpsd-keys
  fi
fi

%post
# if temp log files are in /var/tmp, move them back to /var/log
if [ -d /var/tmp/httpd-logs ]; then
  cp -a /var/tmp/httpd-logs/* /var/log/httpd
  rm -fr /var/tmp/httpd-logs
fi

# move old key/certificate if upgrading SWS 1.x/2.x
if [ -d /var/tmp/httpsd-keys ]; then
  mv /var/tmp/httpsd-keys/httpsd.key /etc/httpd/conf/ssl.key/server.key
  mv /var/tmp/httpsd-keys/httpsd.crt /etc/httpd/conf/ssl.crt/server.crt
  rmdir /var/tmp/httpsd-keys
fi

/sbin/chkconfig --add httpsd
[ -f /etc/mime.types ] || exit 0
# safely add .htm to mime types if it is not already there
TEMPTYPES=`/bin/mktemp /tmp/mimetypes.XXXXXX`
[ -z "$TEMPTYPES" ] && {
  echo "could not make temporary file, htm not added to /etc/mime.types" >&2
  exit 1
}
( grep -v "^text/html"  /etc/mime.types
  types=$(grep "^text/html" /etc/mime.types | cut -f2-)
  echo -en "text/html\t\t\t"
  for val in $types ; do
      if [ "$val" = "htm" ] ; then
          continue
      fi
      echo -n "$val "
  done
  echo "htm"
) > $TEMPTYPES
cat $TEMPTYPES > /etc/mime.types && /bin/rm -f $TEMPTYPES

%preun
if [ $1 = 0 ]; then
   /etc/rc.d/init.d/httpsd stop > /dev/null 2>&1
   /sbin/chkconfig --del httpsd
   /bin/rm -fr /var/run/ssl_mutex
   /bin/rm -fr /var/cache/ssl_scache
   /bin/rm -fr /var/cache/httpd/*
fi
  
%files
%defattr(-,root,root)
%dir /etc/httpd/conf
%dir /etc/httpd/conf/ssl.crt
%attr(0755,root,root) /etc/httpd/conf/ssl.crt/Makefile
/etc/httpd/conf/ssl.crt/ca-bundle.crt
/etc/httpd/conf/ssl.crt/snakeoil-rsa.crt
%dir /etc/httpd/conf/ssl.csr
%dir /etc/httpd/conf/ssl.key
/etc/httpd/conf/ssl.key/snakeoil-rsa.key
%dir /etc/httpd/conf/ssl.crl
%dir /etc/httpd/conf/ssl.prm

/etc/httpd/conf/Makefile
%config /etc/httpd/conf/access.conf
%config /etc/httpd/conf/srm.conf
%config /etc/httpd/conf/httpd.conf
/etc/httpd/conf/httpsd.conf
#%config /etc/httpd/conf/magic

/etc/httpd/logs
/etc/httpd/modules
%config /etc/logrotate.d/secureweb
%config /etc/rc.d/init.d/httpsd
%config(missingok) /etc/rc.d/rc3.d/S85httpsd
%config(missingok) /etc/rc.d/rc5.d/S85httpsd
%config(missingok) /etc/rc.d/rc0.d/K15httpsd
%config(missingok) /etc/rc.d/rc1.d/K15httpsd
%config(missingok) /etc/rc.d/rc2.d/K15httpsd
%config(missingok) /etc/rc.d/rc6.d/K15httpsd

%dir /home/httpd
%dir /home/httpd/cgi-bin
%dir /home/httpd/html
%config(noreplace) /home/httpd/html/index.html
/home/httpd/html/logotype.png
/home/httpd/html/rsasec_55_clr_web1.gif
/home/httpd/icons

%config /usr/lib/ssl/openssl.cnf
/usr/lib/apache

/usr/man/man1/*
/usr/man/man8/ab.8
/usr/man/man8/httpsd.8
/usr/man/man8/logresolve.8
/usr/man/man8/rotatelogs.8
/usr/man/man8/suexec.8

/usr/sbin/openssl
/usr/sbin/ab
/usr/sbin/httpsd
/usr/sbin/logresolve
/usr/sbin/rotatelogs
%attr(0711,root,root) /usr/sbin/suexec
/usr/bin/*

%attr(-,nobody,nobody) %dir /var/cache/httpd
%dir /var/log/httpd

%files manual
%defattr(-,root,root)
/home/httpd/html/manual

%files devel
%defattr(-,root,root)
/usr/include/apache
/usr/sbin/apxs
/usr/man/man8/apxs.8

%changelog
* Thu Jan 13 2000 Preston Brown <pbrown@redhat.com>
- updated RSA logo and links
- changed our own images to PNG
- mod_ssl 2.4.10 to fix segfault issues
- fixed testcert target
- merge fixes from latest apache package
- make us provide apache, apache-devel, apache-manual

* Mon Sep 04 1999 Preston Brown <pbrown@redhat.com>
- cleaned up openssl + upgrade version, latest mod_ssl
- index.html updates
- mm integration
 
* Fri May 21 1999 Preston Brown <pbrown@redhat.com>
- more efficient BSAFE <--> EAY RSA conversion code, better BSAFE RC4 code

* Thu Apr 29 1999 Preston Brown <pbrown@redhat.com>
- port secure web server to this version of the spec file

* Wed Apr 07 1999 Bill Nottingham <notting@redhat.com>
- allow indexes in /doc

* Tue Apr 06 1999 Preston Brown <pbrown@redhat.com>
- strip binaries

* Mon Apr 05 1999 Preston Brown <pbrown@redhat.com>
- prerequire /bin/rm, added /doc path pointing to /usr/doc for localhost

* Fri Mar 26 1999 Preston Brown <pbrown@redhat.com>
- updated log rotating scripts to not complain if logs aren't present.

* Thu Mar 25 1999 Preston Brown <pbrown@redhat.com>
- fixed up path to perl

* Wed Mar 24 1999 Preston Brown <pbrown@redhat.com>
- updated init script to conform to new standards
- upgraded to 1.3.6, fixed apxs patch

* Mon Mar 22 1999 Preston Brown <pbrown@redhat.com>
- clean up logfiles on deinstallation

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Fri Mar 12 1999 Cristian Gafton <gafton@redhat.com>
- added mod_bandwidth
- updated to 1.3.4
- prereq mailcap

* Fri Dec 18 1998 Cristian Gafton <gafton@redhat.com>
- added patch to disable building support for ndbm
- build against glibc 2.1

* Mon Oct 12 1998 Cristian Gafton <gafton@redhat.com>
- updated to 1.3.3 to catch up with bug fixes
- added the /usr/bin/* binaries to the spec file list

* Fri Sep 25 1998 Cristian Gafton <gafton@redhat.com>
- change ownership of cache dir to nobody
- added "Red Hat" to the server string
- updated to version 1.3.2
- fixed all references to httpsd in config files

* Fri Sep 04 1998 Cristian Gafton <gafton@redhat.com>
- small fixes to the spec file
- patch to handle correctly the -d <newroot> option
- leave out the .usr.src.apache_%{version} for now

* Thu Sep 03 1998 Preston Brown <pbrown@redhat.com>
- patched apxs not to bomb out if it can't find httpd

* Wed Sep 02 1998 Preston Brown <pbrown@redhat.com>
- upgraded to apache 1.3.1.
- Heavy rewrite.
- changed providing a_web_server to just webserver.  Humor is not an option.

* Mon Aug 10 1998 Erik Troan <ewt@redhat.com>
- updated to build as non-root user
- added patch to defeat header dos attack

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Wed May 06 1998 Cristian Gafton <gafton@redhat.com>
- fixed the default config files to be more paranoid about security

* Sat May 02 1998 Cristian Gafton <gafton@redhat.com>
- fixed init script
- added index.htm to the list of acceptable indexes

* Sat May 02 1998 Cristian Gafton <gafton@redhat.com>
- updated to 1.2.6
- added post script to install htm extension for text/html into
  /etc/mime.types

* Wed Apr 22 1998 Michael K. Johnson <johnsonm@redhat.com>
- enhanced sysv init script

* Tue Jan 06 1998 Erik Troan <ewt@redhat.com>
- updated to 1.2.5, which includes many security fixes

* Wed Dec 31 1997 Otto Hammersmith <otto@redhat.com>
- fixed overkill on http.init stop

* Wed Dec 31 1997 Erik Troan <ewt@redhat.com>
- added patch for backslash DOS attach

* Thu Nov 06 1997 Donnie Barnes <djb@redhat.com>
- added htdigest binary to file list

* Mon Nov 03 1997 Donnie Barnes <djb@redhat.com>
- made the default index.html be config(noreplace) so we no longer
  blow away other folks' index.html

* Wed Oct 29 1997 Donnie Barnes <djb@redhat.com>
- added chkconfig support
- added restart|status options to initscript
- renamed httpd.init to httpd

* Tue Oct 07 1997 Elliot Lee <sopwith@redhat.com>
- Redid spec file, patches, etc. from scratch.
